=========================
Kuryr-libnetwork overview
=========================

Kuryr-libnetwork is Kuryr's Docker libnetwork driver that uses Neutron to
provide networking services. It provides containerised images for the common
Neutron plugins.

Features
--------

* Docker libnetwork remote driver

* Docker libnetwork IPAM driver

* Support both IPv4 and IPv6

* Support for Linux Bridge, Open vSwitch, Midonet, and IOvisor port bindings

* Support for using existing Neutron networks.

* Support for using existing Neutron ports.

* Support for the Docker "expose" option.
